//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/Bin.h
//! @brief     Defines structs Bin1D, Bin1DCVector
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_BASE_AXIS_BIN_H
#define BORNAGAIN_BASE_AXIS_BIN_H

#include <heinz/Vectors3D.h>

class Bin1D {
public:
    Bin1D() = default;
    Bin1D(double lower, double upper)
        : m_lower(lower)
        , m_upper(upper)
    {
    }
    double m_lower{0}; //!< lower bound of the bin
    double m_upper{0}; //!< upper bound of the bin
    double center() const { return (m_lower + m_upper) / 2.0; }
    double binSize() const { return m_upper - m_lower; }
};

#endif // BORNAGAIN_BASE_AXIS_BIN_H
