//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/VariableBinAxis.h
//! @brief     Defines class VariableBinAxis.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_BASE_AXIS_VARIABLEBINAXIS_H
#define BORNAGAIN_BASE_AXIS_VARIABLEBINAXIS_H

#include "Base/Axis/IAxis.h"

//! Axis with variable bin size.

class VariableBinAxis : public IAxis {
public:
    //! VariableBinAxis constructor.
    //! @param name Axis name
    //! @param bin_boundaries Array of size nbins+1 containing low-edges for each
    //! bin and upper edge of last bin.
    VariableBinAxis(const std::string& name, const std::vector<double>& bin_boundaries);
    ~VariableBinAxis() override = default;

    VariableBinAxis* clone() const override;

    size_t size() const override { return m_nbins; }

    double operator[](size_t index) const override;

    Bin1D bin(size_t index) const override;

    double min() const override;
    double max() const override;

    double binCenter(size_t index) const override;

    size_t findClosestIndex(double value) const override;

    std::vector<double> binCenters() const override;
    std::vector<double> binBoundaries() const override { return m_bin_boundaries; }

    void clip(double lower, double upper) override;

protected:
    explicit VariableBinAxis(const std::string& name, size_t nbins = 0);
    void setBinBoundaries(const std::vector<double>& bin_boundaries);

    void print(std::ostream& ostr) const override;
    bool equals(const IAxis& other) const override;
    size_t m_nbins;

private:
    std::vector<double> m_bin_boundaries; //!< vector containing the bin limits
};

#endif // BORNAGAIN_BASE_AXIS_VARIABLEBINAXIS_H
