//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/IO/ReadWriteINT.h
//! @brief     Defines ReadWriteINT
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_DEVICE_IO_READWRITEINT_H
#define BORNAGAIN_DEVICE_IO_READWRITEINT_H

#include <istream>
#include <vector>

class Datafield;

//! Class for reading and writing BornAgain native IntensityData from ASCII file.

class ReadWriteINT {
public:
    Datafield* readDatafield(std::istream& input_stream);
    void writeDatafield(const Datafield& data, std::ostream& output_stream);

private:
    static void writeDatafieldDoubles(const std::vector<double>& dataValues,
                                      std::ostream& output_stream, size_t n_columns);
    static double ignoreDenormalized(double value);
};

#endif // BORNAGAIN_DEVICE_IO_READWRITEINT_H
