//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/IO/ReadWriteTiff.h
//! @brief     Defines class ReadWriteTiff
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_DEVICE_IO_READWRITETIFF_H
#define BORNAGAIN_DEVICE_IO_READWRITETIFF_H

#ifdef BA_TIFF_SUPPORT

#include <cstdint>
#include <memory>
#include <tiffio.h>

class Datafield;

//! Reads/write tiff files.

class ReadWriteTiff {
public:
    ReadWriteTiff();
    ~ReadWriteTiff();

    Datafield* readDatafield(std::istream& input_stream);
    void writeDatafield(const Datafield& data, std::ostream& output_stream);

private:
    void read(std::istream& input_stream);
    void read_header();
    void read_data();
    void write_header();
    void write_data();
    void close();
    void create_output_data();

    TIFF* m_tiff;
    size_t m_width, m_height;
    uint16_t m_bitsPerSample, m_samplesPerPixel, m_sampleFormat;
    std::unique_ptr<Datafield> m_data;
};

#endif // BA_TIFF_SUPPORT

#endif // BORNAGAIN_DEVICE_IO_READWRITETIFF_H
