//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Pol/PolFilter.h
//! @brief     Defines class DetectionProperties.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_DEVICE_POL_POLFILTER_H
#define BORNAGAIN_DEVICE_POL_POLFILTER_H

#include "Param/Node/INode.h"
#include <heinz/Vectors3D.h>

class SpinMatrix;

//! Detector properties (efficiency, transmission).

class PolFilter : public INode {
public:
    PolFilter(R3 direction, double efficiency, double total_transmission);
    PolFilter();
    ~PolFilter() override = default;

    std::string className() const final { return "PolFilter"; }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Efficiency", ""}, {"Transmission", ""}};
    }

    //! Return the polarization density matrix (in spin basis along z-axis)
    SpinMatrix matrix() const;

    //! Retrieve the analyzer characteristics
    R3 analyzerDirection() const;
    double analyzerEfficiency() const; //!< will always return positive value
    double totalTransmission() const;

private:
    R3 m_direction;              //!< direction of polarization analysis
    double m_efficiency;         //!< efficiency of polarization analysis
    double m_total_transmission; //!< total transmission of polarization analysis
};

#endif // BORNAGAIN_DEVICE_POL_POLFILTER_H
