# Functional test: Magnetic cylinders in DWBA with zero magnetic field

import bornagain as ba
from bornagain import ba_plot as bp, deg, nm, R3


def get_sample():
    # defining materials
    mAmbience = ba.RefractiveMaterial("Vacuum", 0, 0)
    mSubstrate = ba.RefractiveMaterial("Substrate", 6e-6, 2e-8)

    magnetic_field = R3(0, 0, 0)

    magParticle = ba.RefractiveMaterial("magParticle", 6e-4, 2e-8,
                                        magnetic_field)
    # collection of particles
    cylinder_ff = ba.Cylinder(5*nm, 5*nm)
    cylinder = ba.Particle(magParticle, cylinder_ff)

    particle_layout = ba.ParticleLayout()
    particle_layout.addParticle(cylinder, 1)
    interference = ba.InterferenceNone()
    particle_layout.setInterference(interference)

    # vacuum layer with particles and substrate form multi layer
    vacuum_layer = ba.Layer(mAmbience)
    vacuum_layer.addLayout(particle_layout)
    substrate_layer = ba.Layer(mSubstrate, 0)
    sample = ba.MultiLayer()
    sample.addLayer(vacuum_layer)
    sample.addLayer(substrate_layer)

    return sample


def get_simulation(sample):
    n = bp.simargs['n']
    beam = ba.Beam(1e2, 0.1*nm, 0.2*deg)
    detector = ba.SphericalDetector(n, 0, 2*deg, n, 0, 2*deg)
    simulation = ba.ScatteringSimulation(beam, sample, detector)
    return simulation


def simulate():
    sample = get_sample()
    simulation = get_simulation(sample)
    return simulation.simulate()


if __name__ == '__main__':
    bp.parse_args(sim_n=100)
    sample = get_sample()
    simulation = get_simulation(sample)
    bp.plot_simulation_result(simulation.simulate())
