#!/usr/bin/env python3
"""
Plot an SLD profile for a sample with a sliced particle layer.
"""

import bornagain as ba
from bornagain import angstrom, ba_plot as bp, deg, nm, sample_tools
import numpy as np
import matplotlib.pyplot as plt


def get_sample():
    # materials
    m_ambient = ba.MaterialBySLD("Ambient", 0, 0)
    m_particle = ba.MaterialBySLD("Particle", 5e-6, 0)
    m_substrate = ba.MaterialBySLD("SiSubstrate", 2.0704e-06, 0)

    # layers
    ambient_layer = ba.Layer(m_ambient)
    substrate_layer = ba.Layer(m_substrate)

    # particle layout
    ff = ba.Cone(5*nm, 10*nm, 75*deg)
    particle = ba.Particle(m_particle, ff)
    layout = ba.ParticleLayout()
    layout.addParticle(particle)
    iff = ba.Interference2DLattice(ba.SquareLattice2D(10*nm, 0))
    layout.setInterference(iff)
    ambient_layer.addLayout(layout)
    ambient_layer.setNumberOfSlices(20)

    # sample
    sample = ba.MultiLayer()
    sample.addLayer(ambient_layer)
    sample.addLayer(substrate_layer)

    return sample


if __name__ == '__main__':
    bp.parse_args()

    sample = get_sample()
    zpoints, slds = sample_tools.materialProfile(sample, 400)

    plt.figure()
    plt.plot(zpoints, np.real(slds))

    bp.show_or_export()
