//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Data/JobItemUtils.h
//! @brief     Defines namespace GUI::Model::JobItemUtils
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DATA_JOBITEMUTILS_H
#define BORNAGAIN_GUI_MODEL_DATA_JOBITEMUTILS_H

#include "Device/Detector/IDetector.h"
#include "GUI/Model/Data/ComboProperty.h"

class DataItem;
class InstrumentItem;
class InstrumentItem;
class SimulationResult;
class ICoordSystem;

//! Contains convenience methods to trasfer data from domain simulation to IntensityDataItem.
//! Used to modify Datafield's axes units as requested by IntensityDataItem.

namespace GUI::Model::JobItemUtils {

//! updates axes of Datafield in IntensityData item
void updateDataAxes(DataItem* dataItem, const InstrumentItem* instrumentItem);

void setDataItemCoords(DataItem* dataItem, const InstrumentItem* instrumentItem);

void setDataItemCoords(DataItem* dataItem, const ICoordSystem& converter);

void createDefaultDetectorMap(DataItem* dataItem, const InstrumentItem* instrumentItem);

//! Sets simulation results into the DataItem
void setResults(DataItem* dataItem, const SimulationResult& result);

ComboProperty availableUnits(const ICoordSystem& converter);

} // namespace GUI::Model::JobItemUtils

#endif // BORNAGAIN_GUI_MODEL_DATA_JOBITEMUTILS_H
