//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/AxisItems.h
//! @brief     Defines various axis items
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DEVICE_AXISITEMS_H
#define BORNAGAIN_GUI_MODEL_DEVICE_AXISITEMS_H

#include <QObject>

class IAxis;
class QXmlStreamReader;
class QXmlStreamWriter;

class BasicAxisItem : public QObject {
    Q_OBJECT

public:
    explicit BasicAxisItem(QObject* parent = nullptr);
    ~BasicAxisItem() override;

    virtual void writeTo(QXmlStreamWriter* w) const;
    virtual void readFrom(QXmlStreamReader* r);

public:
    virtual std::unique_ptr<IAxis> createAxis(double scale) const;

    int binCount() const;
    void setBinCount(size_t value);

    double min() const;
    void setMin(double value);

    double max() const;
    void setMax(double value);

    QString title() const;
    void setTitle(const QString& title);

    bool isVisible() const;
    void setVisible(bool b);

signals:
    void axisRangeChanged();
    void axisTitleChanged();
    void axisVisibilityChanged();

private:
    bool m_visible;
    int m_nbins;
    double m_minDeg;
    double m_maxDeg;
    QString m_title;
};

class AmplitudeAxisItem : public BasicAxisItem {
    Q_OBJECT

public:
    explicit AmplitudeAxisItem(QObject* parent = nullptr);

    void writeTo(QXmlStreamWriter* w) const override;
    void readFrom(QXmlStreamReader* r) override;

    bool isLogScale() const;
    void setLogScale(bool value);

    bool isLocked() const;
    void setLocked(bool locked);

signals:
    void logScaleChanged(bool isLog);

private:
    bool m_lockMinMax;
    bool m_logScale;
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_AXISITEMS_H
