//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/InstrumentNotifier.cpp
//! @brief     Implements class InstrumentNotifier
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Device/InstrumentNotifier.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/MultiInstrumentNotifier.h"
#include "GUI/Model/Device/PointwiseAxisItem.h"

InstrumentNotifier::InstrumentNotifier(MultiInstrumentNotifier* ec, InstrumentItem* instrument)
    : m_instrumentItem(instrument)
    , m_ec(ec)
{
}

void InstrumentNotifier::setInstrumentName(const QString& name)
{
    m_ec->setInstrumentName(m_instrumentItem, name);
}

void InstrumentNotifier::notifyInstrumentChanged()
{
    m_ec->instrumentChanged(m_instrumentItem);
}

void InstrumentNotifier::notifyWavelengthDistributionChanged()
{
    // Update values in pointwise axis. This is necessary after a change of the mean wavelength.
    if (auto* iiI = dynamic_cast<SpecularInstrumentItem*>(m_instrumentItem)) {
        if (auto* pw = dynamic_cast<PointwiseAxisItem*>(iiI->scanItem()->inclinationAxisItem()))
            pw->updateIndicators();
    }

    m_ec->instrumentChanged(m_instrumentItem);
}

void InstrumentNotifier::notifyInclinationAxisChanged()
{
    m_ec->instrumentChanged(m_instrumentItem);
}
