//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/OffspecDetectorItem.h
//! @brief     Defines class OffspecDetectorItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DEVICE_OFFSPECDETECTORITEM_H
#define BORNAGAIN_GUI_MODEL_DEVICE_OFFSPECDETECTORITEM_H

#include "GUI/Model/Descriptor/AxisProperty.h"

class OffspecDetector;

class OffspecDetectorItem {
public:
    OffspecDetectorItem();

    void writeTo(QXmlStreamWriter* w) const;
    void readFrom(QXmlStreamReader* r);

    int xSize() const;
    int ySize() const;
    void setXSize(size_t nx);
    void setYSize(size_t ny);

    double axesToCoreUnitsFactor() const;

    AxisProperty& phiAxis() { return m_phiAxis; }
    const AxisProperty& phiAxis() const { return m_phiAxis; }

    AxisProperty& alphaAxis() { return m_alphaAxis; }
    const AxisProperty& alphaAxis() const { return m_alphaAxis; }

    std::unique_ptr<OffspecDetector> createOffspecDetector() const;

private:
    AxisProperty m_phiAxis;
    AxisProperty m_alphaAxis;
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_OFFSPECDETECTORITEM_H
