//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/IO/DataLoaders1D.cpp
//! @brief     Implements class DataLoaders1D
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/IO/DataLoaders1D.h"
#include "GUI/Support/IO/AbstractDataLoader1D.h"

DataLoaders1D::~DataLoaders1D()
{
    qDeleteAll(m_builtInLoaders);
    qDeleteAll(m_userDefinedLoaders);
}

DataLoaders1D& DataLoaders1D::instance()
{
    static DataLoaders1D inst;

    return inst;
}

void DataLoaders1D::addBuiltInLoader(const QString& name,
                                     const std::function<AbstractDataLoader1D*()>& create)
{
    m_createLoaders.emplace(name, create);
    m_builtInLoaders.push_back(create());
}

void DataLoaders1D::addUserDefinedLoader(AbstractDataLoader1D* loader)
{
    m_userDefinedLoaders.push_back(loader);
}

QVector<AbstractDataLoader1D*> DataLoaders1D::loaders() const
{
    return m_builtInLoaders + m_userDefinedLoaders;
}

QVector<AbstractDataLoader1D*> DataLoaders1D::recentlyUsedLoaders() const
{
    return m_recentlyUsedLoaders;
}

AbstractDataLoader1D* DataLoaders1D::createFromPersistentName(const QString& persistentClassName)
{
    auto it = m_createLoaders.find(persistentClassName);

    if (it != m_createLoaders.end())
        return it->second();
    return nullptr;
}
