//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Fit/FitSessionManager.cpp
//! @brief     Implements class FitSessionManager
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Fit/FitSessionManager.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/Support/Util/Error.h"
#include "GUI/View/Fit/FitSessionController.h"

FitSessionManager::FitSessionManager(QObject* parent)
    : QObject(parent)
    , m_activeController(nullptr)
{
}

FitSessionManager::~FitSessionManager()
{
    for (auto* jobItem : m_item_to_controller.keys())
        disconnect(jobItem, nullptr, this, nullptr);
}

FitSessionController* FitSessionManager::sessionController(JobItem* jobItem)
{
    FitSessionController* result(nullptr);

    auto it = m_item_to_controller.find(jobItem);
    if (it == m_item_to_controller.end()) {
        result = createController(jobItem);
        m_item_to_controller.insert(jobItem, result);
    } else {
        result = it.value();
    }

    m_activeController = result;

    return result;
}

FitSessionController* FitSessionManager::createController(JobItem* jobItem)
{
    connect(jobItem, &JobItem::destroyed, this, [=]() { removeController(jobItem); });

    auto* result = new FitSessionController(this);
    result->setJobItem(jobItem);
    return result;
}

//! Removes manager for given jobItem

void FitSessionManager::removeController(JobItem* jobItem)
{
    auto it = m_item_to_controller.find(jobItem);
    if (it == m_item_to_controller.end())
        throw Error("FitActivityManager::removeFitSession -> Error. "
                    "Cannot find fit session");

    if (m_activeController == it.value())
        m_activeController = nullptr;
    delete it.value();
    m_item_to_controller.erase(it);
}
