//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Loaders/AutomaticDataLoader1D.h
//! @brief     Defines class AutomaticDataLoader1D
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LOADERS_AUTOMATICDATALOADER1D_H
#define BORNAGAIN_GUI_VIEW_LOADERS_AUTOMATICDATALOADER1D_H

#include "Device/Data/Datafield.h"
#include "GUI/Support/IO/AbstractDataLoader1D.h"

//! The legacy importer for reflectometry, with no user interaction.

class AutomaticDataLoader1D : public AbstractDataLoader1D {
public:
    QString name() const override;
    QString persistentClassName() const override;
    AbstractDataLoader* clone() const override;
    QByteArray serialize() const override;
    void deserialize(const QByteArray& data) override;
    void setFileContents(const QByteArray& fileContent) override;
    QByteArray fileContent() const override;
    void processContents() override;
    AbstractDataLoaderResultModel* createResultModel() const override;
    int numErrors() const override;
    QStringList lineUnrelatedErrors() const override;

private:
    QByteArray m_fileContent;
    QString m_error;
};

#endif // BORNAGAIN_GUI_VIEW_LOADERS_AUTOMATICDATALOADER1D_H
