//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Loaders/DataLoaderUtil.cpp
//! @brief     Implements class UserDefinedDataLoader1D
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Loaders/DataLoaderUtil.h"
#include "GUI/Support/IO/DataLoaders1D.h"
#include "GUI/View/Loaders/AutomaticDataLoader1D.h"
#include "GUI/View/Loaders/QREDataLoader.h"
#include "GUI/View/Loaders/UserDefinedDataLoader1D.h"

void cloneAsUserDefinedLoader(AbstractDataLoader1D* loader, const QString& name)
{
    loader->applyImportSettings();
    auto* clonedLoader = dynamic_cast<AbstractDataLoader1D*>(loader->clone());
    const auto defaultProperties = loader->serialize();

    DataLoaders1D::instance().addUserDefinedLoader(
        new UserDefinedDataLoader1D(clonedLoader, name, defaultProperties));
}


namespace {

//! simple factory method for a QREDataLoader
QREDataLoader* createQREDataLoader()
{
    return new QREDataLoader();
}

//! simple factory method for a AutomaticDataLoader1D
AutomaticDataLoader1D* createAutomaticDataLoader1D()
{
    return new AutomaticDataLoader1D();
}

} // namespace

//! register the concrete data loaders with the registration facility
void register1DDataLoaders()
{
    // the ordering in here defines the ordering in the selection combo box in the open file dialog
    // and also in the selection combo box on the format configuration page. Furthermore the first
    // returned loader will be used as default in the open file dialog if it is started for the
    // first time
    DataLoaders1D::instance().addBuiltInLoader(QREDataLoader().persistentClassName(),
                                               createQREDataLoader);
    DataLoaders1D::instance().addBuiltInLoader(AutomaticDataLoader1D().persistentClassName(),
                                               createAutomaticDataLoader1D);
}
