//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Loaders/QREDataLoaderResultModel.h
//! @brief     Defines class QREDataLoaderResultModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LOADERS_QREDATALOADERRESULTMODEL_H
#define BORNAGAIN_GUI_VIEW_LOADERS_QREDATALOADERRESULTMODEL_H

#include "GUI/Support/IO/AbstractDataLoaderResultModel.h"
#include "GUI/View/Loaders/QREDataLoader.h"

//! The result model of a QREDataLoader (for showing the import results in a table view).
class QREDataLoaderResultModel : public AbstractDataLoaderResultModel {
public:
    QREDataLoaderResultModel(QREDataLoader::ImportResult* importResult);

protected:
    bool rowIsSkipped(int row) const override;
    using AbstractDataLoaderResultModel::rowIsSkipped;
    QString headerTextOfCalculatedColumn(int column) const override;
    int columnCount(ColumnType type) const override;
    using AbstractDataLoaderResultModel::columnCount;
    QString cellText(ColumnType type, int row, int col) const override;
    bool rowHasError(int row) const override;
    using AbstractDataLoaderResultModel::rowHasError;
    int rowCount() const override;
    using AbstractDataLoaderResultModel::rowCount;

private:
    QREDataLoader::ImportResult* m_importResult;
};

#endif // BORNAGAIN_GUI_VIEW_LOADERS_QREDATALOADERRESULTMODEL_H
