//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Loaders/UserDefinedDataLoader1D.h
//! @brief     Defines class UserDefinedDataLoader1D
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LOADERS_USERDEFINEDDATALOADER1D_H
#define BORNAGAIN_GUI_VIEW_LOADERS_USERDEFINEDDATALOADER1D_H

#include "GUI/Support/IO/AbstractDataLoader1D.h"

//! A user defined data loader. This is a thin wrapper around the real loader implementation,
//! storing the relevant settings to make it user definable (namely name and import settings).

class UserDefinedDataLoader1D : public AbstractDataLoader1D {
public:
    UserDefinedDataLoader1D(AbstractDataLoader1D* wrappedLoader, QString name,
                            QByteArray defaultProperties);

    QString name() const override;
    void populateImportSettingsWidget(QWidget* parent) override;
    void initWithDefaultImportSettings() override;
    QString persistentClassName() const override;
    QByteArray serialize() const override;
    void deserialize(const QByteArray& data) override;
    AbstractDataLoader* clone() const override;
    void setFileContents(const QByteArray& fileContent) override;
    void guessSettings() override;
    void processContents() override;

    // #baUserDefLoaders ++ implement all overloads!
private:
    QString m_name;
    AbstractDataLoader1D* m_wrappedLoader;
    QByteArray m_defaultProperties;
};

#endif // BORNAGAIN_GUI_VIEW_LOADERS_USERDEFINEDDATALOADER1D_H
