//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/PlotUtil/RangeUtils.h
//! @brief     Defines RangeUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_PLOTUTIL_RANGEUTILS_H
#define BORNAGAIN_GUI_VIEW_PLOTUTIL_RANGEUTILS_H

#include <QList>

class AmplitudeAxisItem;
class IntensityDataItem;
class SpecularDataItem;
class QCustomPlot;
class QCPAxis;
class QCPColorScale;
class QCPRange;
class QCPColorGradient;

//! Provides few helper functions for ColorMapPlot.

namespace GUI::View::RangeUtils {

//! Returns x-axis range.
QCPRange itemXrange(const IntensityDataItem* item);

//! Returns x-axis vizible range (zoom).
QCPRange itemZoomX(const IntensityDataItem* item);

//! Returns y-axis range.
QCPRange itemYrange(const IntensityDataItem* item);

//! Returns y-axis vizible range (zoom).
QCPRange itemZoomY(const IntensityDataItem* item);

//! Returns z-axis data range.
QCPRange itemDataRange(const IntensityDataItem* item);

//! Returns z-axis visible range (zoom).
QCPRange itemDataZoom(const IntensityDataItem* item);

//! Returns common min for a list of axes (zoom).
double commonMin(const QList<AmplitudeAxisItem*>& axes);

//! Returns common max for a list of axes (zoom).
double commonMax(const QList<AmplitudeAxisItem*>& axes);

//! Returns common range for a list of axes (zoom).
QCPRange commonRange(const QList<AmplitudeAxisItem*>& axes);

//! Sets common Y range for a list of items (zoom).
void setCommonRangeY(QList<SpecularDataItem*> items);

//! Sets common Z range for a list of items (zoom).
void setCommonRangeZ(QList<IntensityDataItem*> items);

//! Gets Y axes from a list of specular items.
QList<AmplitudeAxisItem*> valueAxesFromSpecularItems(const QList<SpecularDataItem*>& items);

//! Gets Z axes from a list of intensity items.
QList<AmplitudeAxisItem*> valueAxesFromIntensityItems(const QList<IntensityDataItem*>& items);

void setLogz(QCPColorScale* scale, bool isLogz);

void setLogz(QCPAxis* axis, bool isLogz);

//! Sets default margins for axes rectangle plot.
void setDefaultMargins(QCustomPlot* customPlot);

QCPColorGradient colorGradientInferno();

} // namespace GUI::View::RangeUtils

#endif // BORNAGAIN_GUI_VIEW_PLOTUTIL_RANGEUTILS_H
