//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Element/DepthprobeElement.cpp
//! @brief     Implements class DepthprobeElement.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/Element/DepthprobeElement.h"
#include "Base/Axis/IAxis.h"
#include "Base/Util/Assert.h"
#include "Base/Vector/GisasDirection.h"

DepthprobeElement::DepthprobeElement(double wavelength, double alpha_i, const IAxis* z_positions,
                                     bool calculation_flag)
    : IElement()
    , m_wavelength(wavelength)
    , m_alpha_i(alpha_i)
    , m_z_positions(z_positions)
    , m_calculation_flag(calculation_flag)
{
    ASSERT(z_positions);
    m_intensities.resize(z_positions->size(), 0.0);
}

DepthprobeElement::DepthprobeElement(DepthprobeElement&& other) noexcept = default;

DepthprobeElement::~DepthprobeElement() = default;

R3 DepthprobeElement::getKi() const
{
    return vecOfLambdaAlphaPhi(m_wavelength, m_alpha_i);
}
