//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Specular/TransitionMagneticNevot.h
//! @brief     Defines namespace MagneticNevotCroceTransition.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2020
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_RESAMPLE_SPECULAR_TRANSITIONMAGNETICNEVOT_H
#define BORNAGAIN_RESAMPLE_SPECULAR_TRANSITIONMAGNETICNEVOT_H

#include "Base/Spin/SpinMatrix.h"
#include <utility>

class MatrixFlux;

//! Implements the magnetic Fresnel computation with Nevot-Croce roughness
//!
//! Implements the transfer matrix formalism for the calculation of wave
//! amplitudes of the coherent wave solution in a sample with magnetization.
//! For a description, see internal
//! document "Polarized Implementation of the Transfer Matrix Method"

namespace Compute::MagneticNevotCroceTransition {

std::pair<SpinMatrix, SpinMatrix> backwardsSubmatrices(const MatrixFlux& coeff_i,
                                                       const MatrixFlux& coeff_i1, double sigma);
}

#endif // BORNAGAIN_RESAMPLE_SPECULAR_TRANSITIONMAGNETICNEVOT_H
