//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Computation/DWBAComputation.h
//! @brief     Defines class DWBAComputation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_SIM_COMPUTATION_DWBACOMPUTATION_H
#define BORNAGAIN_SIM_COMPUTATION_DWBACOMPUTATION_H

#include "Base/Types/OwningVector.h"
#include "Sim/Computation/IComputation.h"
#include <vector>

class DiffuseElement;
class ReSample;
class SimulationOptions;

//! Provides function that performs a single-threaded DWBA computation
//! for a range of DiffuseElement%s.
//!
//! Handles progress counter and interrupts, runs loop over DiffuseElement%s,
//! delegates all further work to DWBATerm.
//!
//! Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

class DWBAComputation : public IComputation {
public:
    DWBAComputation(const ReSample& re_sample, const SimulationOptions& options,
                    ProgressHandler& progress);
    ~DWBAComputation() override;

    double simulatedIntensity(DiffuseElement& ele);
};

#endif // BORNAGAIN_SIM_COMPUTATION_DWBACOMPUTATION_H
