//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Computation/DepthprobeComputation.h
//! @brief     Declares class DepthprobeComputation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_SIM_COMPUTATION_DEPTHPROBECOMPUTATION_H
#define BORNAGAIN_SIM_COMPUTATION_DEPTHPROBECOMPUTATION_H

#include "Sim/Computation/IComputation.h"
#include <vector>

class DepthprobeElement;
class ReSample;

//! Performs a single-threaded depth probe computation with given sample.
//!
//! Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

class DepthprobeComputation : public IComputation {
public:
    DepthprobeComputation(const ReSample& re_sample, const SimulationOptions& options,
                          ProgressHandler& progress);
    ~DepthprobeComputation() override;

    void run(DepthprobeElement& ele);
};

#endif // BORNAGAIN_SIM_COMPUTATION_DEPTHPROBECOMPUTATION_H
