//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Computation/IComputation.cpp
//! @brief     Implements interface IComputation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sim/Computation/IComputation.h"
#include "Base/Progress/ProgressHandler.h"
#include "Resample/Processed/ReSample.h"

IComputation::IComputation(const ReSample& re_sample, const SimulationOptions& options,
                           ProgressHandler& progress)
    : m_re_sample(re_sample)
    , m_options(options)
    , m_progress(progress)
{
}

IComputation::~IComputation() = default;

void IComputation::stepProgress() const
{
    m_progress.incrementDone(1);
}
