//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Computation/IComputation.h
//! @brief     Defines interface IComputation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_SIM_COMPUTATION_ICOMPUTATION_H
#define BORNAGAIN_SIM_COMPUTATION_ICOMPUTATION_H

class ReSample;
class ProgressHandler;
class SimulationOptions;

//! Interface for a single-threaded computation with given range of DiffuseElement%s
//! and ProgressHandler.
//!
//! Controlled by the multi-threading machinery in ISimulation::runSingleSimulation().

class IComputation {
public:
    IComputation(const ReSample& re_sample, const SimulationOptions& options,
                 ProgressHandler& progress);
    virtual ~IComputation();

    //! Runs computation. May throw.
    virtual void runProtected() {}

protected:
    void stepProgress() const;

    const ReSample& m_re_sample;
    const SimulationOptions& m_options;

private:
    ProgressHandler& m_progress;
};

#endif // BORNAGAIN_SIM_COMPUTATION_ICOMPUTATION_H
