//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Contrib/GISASSpecularContribution.cpp
//! @brief     Implements class GISASSpecularContribution.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sim/Contrib/GISASSpecularContribution.h"
#include "Base/Util/Assert.h"
#include "Resample/Element/DiffuseElement.h"
#include "Resample/Flux/ScalarFlux.h"

double compute::gisasSpecularContribution(const DiffuseElement& ele)
{
    if (!ele.isSpecular())
        return 0;

    const auto* flux = dynamic_cast<const ScalarFlux*>(ele.fluxIn(0));
    if (!flux)
        throw std::runtime_error("Specular intensity not yet implemented for polarized neutrons"
                                 " (https://jugit.fz-juelich.de/mlz/bornagain/-/issues/541)");
    complex_t R = flux->getScalarR();

    double sin_alpha_i = std::abs(std::sin(ele.alphaI()));
    if (sin_alpha_i == 0.0)
        return 0;

    const double solid_angle = ele.solidAngle();
    if (solid_angle <= 0.0)
        return 0;

    return std::norm(R) * sin_alpha_i / solid_angle;
}
