#!/bin/env python3
"""
"""

import glob, os, sys
import bornagain as ba


def main(datstem, refstem, tolerance):
    os.makedirs(os.path.dirname(datstem), exist_ok=True)

    datfile = datstem + ".int.gz"
    reffile = refstem + ".int.gz"

    datmatches = glob.glob(datstem + ".*.int.gz")
    refmatches = glob.glob(refstem + ".*.int.gz")
    n_subfiles = max(len(datmatches), len(refmatches))

    if n_subfiles == 0:

        ok = ba.filesAgree(datfile, reffile, tolerance)
        if not ok:
            print(
                f"=> no agreement between result and reference: {datfile} {reffile}",
                flush=True)
            return 1
        return 0

    # we do have subfiles
    if os.path.exists(datfile):
        if len(datmatches) > 0:
            raise Exception(
                f"Test output contains unnumbered and numbered files: {datfile} "
                + "vs {datmatches}")
        raise Exception(
            f"Test output contains unnumbered file {datfile} "
            "while there are numbered reference files {refmatches}")
    if os.path.exists(reffile):
        if len(refmatches) > 0:
            raise Exception(
                f"Reference contains unnumbered and numbered files: {reffile} "
                + "vs {refmatches}")
        raise Exception(
            f"Reference contains unnumbered file {reffile} "
            "while there are numbered test output files {datmatches}")

    if len(datmatches) < len(refmatches):
        raise Exception(
            f"There are less test output files than reference files: " +
            "{datmatches} vs {refmatches}")
    if len(datmatches) > len(refmatches):
        raise Exception(
            f"There are more test output files than reference files: " +
            "{datmatches} vs {refmatches}")

    ok = True
    for i in range(n_subfiles):
        datfile = datstem + "." + str(i) + ".int.gz"
        reffile = refstem + "." + str(i) + ".int.gz"
        ret = ba.filesAgree(datfile, reffile, tolerance)
        if not ret:
            print(
                f"=> no agreement between result and reference: {datfile} {reffile}",
                flush=True)
            ok = False
    if not ok:
        return 1
    return 0


if __name__ == '__main__':
    if len(sys.argv) != 4:
        raise Exception(f'{sys.argv[0]}: invalid arguments. Expected: ' +
                        'datstem refstem tolerance')
    datstem, refstem = sys.argv[1:3]
    tolerance = float(sys.argv[3])
    ret = main(datstem, refstem, tolerance)
    sys.exit(ret)
