// ************************************************************************** //
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Wrap/Swig/libBornAgainBase.i
//! @brief     SWIG interface file for libBornAgainBase
//!
//! @homepage  http://apps.jcns.fz-juelich.de/BornAgain
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2013
//! @authors   Scientific Computing Group at MLZ Garching
//
// ************************************************************************** //

%module(directors="1", moduleimport="import $module") "libBornAgainBase"

%include "commons.i"


%{
#include <heinz/Complex.h>
#include "Base/Types/ICloneable.h"
#include "Base/Types/Span.h"
#include "Base/Const/Units.h"
#include "Base/Util/ThreadInfo.h"
#include "Base/Axis/Bin.h"
#include "Base/Axis/VariableBinAxis.h"
#include "Base/Axis/ConstKBinAxis.h"
#include "Base/Axis/CustomBinAxis.h"
#include "Base/Axis/FixedBinAxis.h"
#include "Base/Axis/PointwiseAxis.h"
#include "Base/Axis/Frame.h"
#include "Base/Vector/RotMatrix.h"
%}

%include "heinz/Complex.h"
%include "Base/Types/ICloneable.h"
%include "Base/Types/Span.h"

%include "Base/Util/ThreadInfo.h"

%include "Base/Const/Units.h"

%include "heinz/Vectors3D.h"
%include "Base/Vector/RotMatrix.h"

%include "Base/Axis/Bin.h"
%include "Base/Axis/IAxis.h"
%include "Base/Axis/VariableBinAxis.h"
%include "Base/Axis/ConstKBinAxis.h"
%include "Base/Axis/CustomBinAxis.h"
%include "Base/Axis/FixedBinAxis.h"
%include "Base/Axis/PointwiseAxis.h"
%include "Base/Axis/Frame.h"

%template(R3) Vec3<double>;
%template(C3) Vec3<std::complex<double>>;

%extend FixedBinAxis {
    double __getitem__(unsigned int i) { return (*($self))[i]; }
};

%extend VariableBinAxis {
    double __getitem__(unsigned int i) { return (*($self))[i]; }
};
