+++
title = "Understand the syntax"
weight = 30
+++

## Python syntax used in BornAgain scripts

We shall employ the same reflectometry script
as on the [preceding page](/py/start/run.md)
to explain some Python syntax used in BornAgain scripts.

For easy reference, here again the full script:

{{< highlightfile file="Examples/specular/AlternatingLayers1.py">}}
<p>

We shall now explain the code.

The [shebang](https://en.wikipedia.org/wiki/Shebang_(Unix)) line
```python
#!/usr/bin/env python3
```
makes the script executable under Unix-like operating systems,
see the chapter on [how to run](/py/start/run.md) scripts
from the command line.

Lines between triple quotes
```python
"""
Text, text, text
"""
```
are comments.

The function
```python
def get_sample():
    ...
```
constructs and returns a sample model.
For more information, see the [sample](/ref/sample) section.

The function
```python
def get_simulation(sample, scan_size=500):
    ...
```
constructs and returns a simulation model.
For more information, see the [simulation](/ref/sim) section,
and specifically the [reflectometry](/ref/sim/class/specular) reference.


The clause
```python
if __name__ == '__main__':
```
ensures that the following statements are only executed
if the script is called directly, as a "main" program.
This precaution is required by the GUI, where scripts can be imported without
being immediately executed.

The line
```python
bp.parse_args(sim_n=500)
```
digests some command-line arguments
that are mostly needed by the developers for automatized testing.

The lines
```python
sample = get_sample()
    simulation = get_simulation(sample)
    result = simulation.simulate()
```
construct a sample and instrument model and run a simulation.
The function `simulate()` returns a
[SimulationResult](/ref/sim/simulation-result) instance.

The line
```python
bp.plot_simulation_result(/py/result)
```
plots the simulated reflectivity as function of the incident glancing angle,
using MatPlotLib.
