+++
title = "Depth probe"
weight = 80
+++

## Depth probe simulation

Depth probe simulation is an auxiliary simulation type, which helps to visualize
the total intensity in dependence on the beam incidence angle and the position in
the sample.

To set up and run a simulation, use
```python
import bornagain as ba
scan = ...
sample = ...
z_axis = ba.FixedBinAxis("z", nz, z_min, z_max)
simulation = ba.DepthprobeSimulation(scan, sample, z_axis)
# ... set options
result = simulation.simulate()
```

For the constructor arguments, see sections [scan](/ref/instr/scan),
[sample](/ref/sample).

For optional settings, see [simulation options](/ref/sim/setup/options).

For the return type of function `simulate()`,
see [SimulationResult](/ref/sim/simulation-result).

### Example

We consider a neutron resonator, composed of one Ti/Pt bilayer.

{{< figscg src="/img/draw/DepthProbeSample.png" width="500" class="center">}}

The beam comes from the Si side.
By convention the beam always comes ''from above''.
Accordingly, we consider Si the ''ambient'' material, placed ''on top'' of the sample.

As a result, we obtain the neutron intensity
as function of depth and incident angle $\alpha_i$.

{{< figscg src="/img/auto/varia/DepthProbe.png" width="500" class="center">}}

{{< highlightfile file="Examples/varia/DepthProbe.py" >}}
